52 void *
u,
int *n,
void *
gd,
int *
nb,
53 void *b,
void *
bo,
int *op,
56 if ((*m) == 0)
return;
59 const dim3 nblcks(((*m)+ 1024 - 1)/ 1024, 1, 1);
66 *
nb, (
int *) b, (
int *)
bo);
73 *
nb, (
int *) b, (
int *)
bo);
80 *
nb, (
int *) b, (
int *)
bo);
87 *
nb, (
int *) b, (
int *)
bo);
97 void *
u,
int *n,
void *
gd,
98 int *
nb,
void *b,
void *
bo,
101 if ((*m) == 0)
return;
104 const dim3 nblcks(((*m)+1024 - 1)/ 1024, 1, 1);
109 *
nb, (
int *) b, (
int *)
bo);
124 (
int *) dof_d + offset, n);
167 int offset,
int n,
int nc,
int ns,
175 (
int *) dof_d + offset, n,
nc,
ns);
184 int offset,
int n,
int nc,
int ns,
194 dof_d + offset, n,
nc,
ns);
199 dof_d + offset, n,
nc,
ns);
204 dof_d + offset, n,
nc,
ns);
__global__ void ale_add_kinematics_kernel(const int n, T *__restrict__ wx, T *__restrict__ wy, T *__restrict__ wz, const T *__restrict__ x_ref, const T *__restrict__ y_ref, const T *__restrict__ z_ref, const T *__restrict__ phi, const T *__restrict__ x, const T *__restrict__ y, const T *__restrict__ z, const kinematics_params_t kin_params)
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ u
__global__ void T *__restrict__ T *__restrict__ const T *__restrict__ const T *__restrict__ v
void cuda_gs_unpack(real *u_d, int op, real *buf_d, int *dof_d, int offset, int n, cudaStream_t stream)
void cuda_gs_pack(void *u_d, void *buf_d, void *dof_d, int offset, int n, cudaStream_t stream)
void cuda_gather_kernel(void *v, int *m, int *o, void *dg, void *u, int *n, void *gd, int *nb, void *b, void *bo, int *op, cudaStream_t stream)
void cuda_scatter_kernel(void *v, int *m, void *dg, void *u, int *n, void *gd, int *nb, void *b, void *bo, cudaStream_t stream)
void cuda_gs_pack_vec(void *u_d, void *buf_d, void *dof_d, int offset, int n, int nc, int ns, cudaStream_t stream)
void cuda_gs_unpack_vec(real *u_d, int op, real *buf_d, int *dof_d, int offset, int n, int nc, int ns, cudaStream_t stream)